@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = 'v0.2.4'; # VERSION
+our $VERSION = 'v0.2.5'; # VERSION
 
 use Moose;
 use namespace::autoclean;
@@ -49,7 +49,7 @@ sub submit {
 			= Business::CyberSource::Response
 			->with_traits(qw{
 				Business::CyberSource::Response::Role::Accept
-				Business::CyberSource::Response::Role::Credit
+				Business::CyberSource::Response::Role::ReconciliationID
 			})
 			->new({
 				request_id     => $r->{requestID},
@@ -61,8 +61,9 @@ sub submit {
 				currency       => $r->{purchaseTotals}->{currency},
 				datetime       => $r->{ccCreditReply}->{requestDateTime},
 				amount         => $r->{ccCreditReply}->{amount},
-				credit_reason_code => "$r->{ccCreditReply}->{reasonCode}",
 				reconciliation_id  => $r->{ccCreditReply}->{reconciliationID},
+				request_specific_reason_code =>
+					"$r->{ccCreditReply}->{reasonCode}",
 			})
 			;
 	}
@@ -88,7 +89,7 @@ Business::CyberSource::Request::Credit - CyberSource Credit Request Object
 
 =head1 VERSION
 
-version v0.2.4
+version v0.2.5
 
 =head1 SYNOPSIS
 
